==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DStaticInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DStaticInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a195ec4a63590b46 soot_dava_internal_javaRep_DStaticInvokeExpr
// @dep_class fdc9ddab507b0298 soot_grimp_internal_GStaticInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GStaticInvokeExpr

#include "soot/grimp/internal/GStaticInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DStaticInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DStaticInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method$_init$6327f5fb7966d9c6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vmethods	soot_grimp_internal_GStaticInvokeExpr;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods	soot_dava_internal_javaRep_DStaticInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs	soot_dava_internal_javaRep_DStaticInvokeExpr;
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs	soot_grimp_internal_GStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs	soot_grimp_internal_GStaticInvokeExpr;
    _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DStaticInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DStaticInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DStaticInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DStaticInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DStaticInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a195ec4a63590b46 soot_dava_internal_javaRep_DStaticInvokeExpr
// @dep_class fdc9ddab507b0298 soot_grimp_internal_GStaticInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GStaticInvokeExpr

#include "soot/grimp/internal/GStaticInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DStaticInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DStaticInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method$_init$6327f5fb7966d9c6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_grimp_internal_GStaticInvokeExpr$vmethods	soot_grimp_internal_GStaticInvokeExpr;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vmethods	soot_dava_internal_javaRep_DStaticInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_refs	soot_dava_internal_javaRep_DStaticInvokeExpr;
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_refs	soot_grimp_internal_GStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_grimp_internal_GStaticInvokeExpr$sub_nonrefs	soot_grimp_internal_GStaticInvokeExpr;
    _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DStaticInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DStaticInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DStaticInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DStaticInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DStaticInvokeExpr_H_ */
